@@ -246,6 +246,10 @@ def _update_highest_version(collection_version):
         last_highest.save()
         collection_version.save()
 
+    elif collection_version.is_highest and collection_version.version != last_highest.version:
+        collection_version.is_highest = False
+        collection_version.save()
+
 
 class AnsibleDeclarativeVersion(DeclarativeVersion):
     """
@@ -407,6 +411,7 @@ class CollectionSyncFirstStage(Stage):
         collection_url = f"{collection_endpoint}{namespace}/{name}"
         collection_metadata_downloader = self.remote.get_downloader(url=collection_url)
         collection_metadata = parse_metadata(await collection_metadata_downloader.run())
+        loop = asyncio.get_event_loop()
 
         tasks = []
         page_num = 1
@@ -426,7 +431,7 @@ class CollectionSyncFirstStage(Stage):
                     if collection_metadata["deprecated"]:
                         self.deprecations |= Q(namespace=namespace, name=name)
                     tasks.append(
-                        asyncio.create_task(
+                        loop.create_task(
                             self._fetch_collection_version_metadata(
                                 api_version,
                                 collection_version_detail_url,
@@ -457,6 +462,7 @@ class CollectionSyncFirstStage(Stage):
 
     async def _find_all_collections(self):
         collection_endpoint, api_version = await self._get_collection_api(self.remote.url)
+        loop = asyncio.get_event_loop()
 
         tasks = []
         page_num = 1
@@ -482,9 +488,7 @@ class CollectionSyncFirstStage(Stage):
                     version="*",
                     source=None,
                 )
-                tasks.append(
-                    asyncio.create_task(self._fetch_collection_metadata(requirements_file))
-                )
+                tasks.append(loop.create_task(self._fetch_collection_metadata(requirements_file)))
 
             next_value = self._get_response_next_value(api_version, collection_list)
             if not next_value:
@@ -498,13 +502,12 @@ class CollectionSyncFirstStage(Stage):
         Build and emit `DeclarativeContent` from the ansible metadata.
         """
         tasks = []
+        loop = asyncio.get_event_loop()
         if self.collection_info:
             for requirement_entry in self.collection_info:
-                tasks.append(
-                    asyncio.create_task(self._fetch_collection_metadata(requirement_entry))
-                )
+                tasks.append(loop.create_task(self._fetch_collection_metadata(requirement_entry)))
         else:
-            tasks.append(asyncio.create_task(self._find_all_collections()))
+            tasks.append(loop.create_task(self._find_all_collections()))
         await asyncio.gather(*tasks)
         self.parsing_metadata_progress_bar.state = TASK_STATES.COMPLETED
         self.parsing_metadata_progress_bar.save()
@@ -600,7 +603,8 @@ class CollectionContentSaver(ContentSaver):
                 continue
             collection_version = d_content.content
             docs_blob = d_content.extra_data.get("docs_blob", {})
-            collection_version.docs_blob = docs_blob
+            if docs_blob:
+                collection_version.docs_blob = docs_blob
 
             for d_artifact in d_content.d_artifacts:
                 artifact = d_artifact.artifact
